@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 - 2009 GraphicsMagick Group
+  Copyright (C) 2003 - 2012 GraphicsMagick Group
   Copyright (C) 2002 ImageMagick Studio
   Copyright 1991-1999 E. I. du Pont de Nemours and Company
  
@@ -232,12 +232,17 @@ typedef enum
   NoCompression,
   BZipCompression,
   FaxCompression,
+  Group3Compression = FaxCompression,
   Group4Compression,
   JPEGCompression,
   LosslessJPEGCompression,
   LZWCompression,
   RLECompression,
-  ZipCompression
+  ZipCompression,
+  LZMACompression,              /* Lempel-Ziv-Markov chain algorithm */
+  JPEG2000Compression,          /* ISO/IEC std 15444-1 */
+  JBIG1Compression,             /* ISO/IEC std 11544 / ITU-T rec T.82 */
+  JBIG2Compression              /* ISO/IEC std 14492 / ITU-T rec T.88 */
 } CompressionType;
 
 typedef enum
@@ -367,7 +372,10 @@ typedef enum
   MultiplicativeGaussianNoise,
   ImpulseNoise,
   LaplacianNoise,
-  PoissonNoise
+  PoissonNoise,
+  /* Below added on 2012-03-17 */
+  RandomNoise,
+  UndefinedNoise
 } NoiseType;
 
 /*
@@ -534,6 +542,15 @@ typedef struct _DoublePixelPacket
     opacity;
 } DoublePixelPacket;
 
+typedef struct _FloatPixelPacket
+{
+  float
+    red,
+    green,
+    blue,
+    opacity;
+} FloatPixelPacket;
+
 /*
   ErrorInfo is used to record statistical difference (error)
   information based on computed Euclidean distance in RGB space.
@@ -717,7 +734,7 @@ typedef struct _Image
     gravity;            /* Image placement gravity */
 
   CompositeOperator
-    compose;            /* Image placement composition */
+    compose;            /* Image placement composition (default OverCompositeOp) */
 
   DisposeType
     dispose;            /* GIF disposal option */
@@ -1000,19 +1017,26 @@ extern MagickExport MagickBool
 
 /* Functions which return unsigned int to indicate operation pass/fail */
 extern MagickExport MagickPassFail
+  AddDefinition(ImageInfo *image_info,const char *magick, const char *key,
+    const char *value, ExceptionInfo *exception),
   AddDefinitions(ImageInfo *image_info,const char *options,
     ExceptionInfo *exception),
   AnimateImages(const ImageInfo *image_info,Image *image),
-  ClipImage(Image *),
+  ClipImage(Image *image),
   ClipPathImage(Image *image,const char *pathname,const MagickBool inside),
   DisplayImages(const ImageInfo *image_info,Image *image),
   RemoveDefinitions(const ImageInfo *image_info,const char *options),
-  SetImage(Image *,const Quantum),
+  ResetImagePage(Image *image,const char *page),
+  SetImage(Image *image,const Quantum),
+  SetImageColor(Image *image,const PixelPacket *pixel),
+  SetImageColorRegion(Image *image,long x,long y,unsigned long width,
+		      unsigned long height,const PixelPacket *pixel),
   SetImageClipMask(Image *image,const Image *clip_mask),
-  SetImageDepth(Image *,const unsigned long),
-  SetImageInfo(ImageInfo *,const MagickBool,ExceptionInfo *),
-  SetImageType(Image *,const ImageType),
-  SyncImage(Image *);
+  SetImageDepth(Image *image,const unsigned long),
+  SetImageInfo(ImageInfo *image_info,const unsigned int flags,ExceptionInfo *exception),
+  SetImageType(Image *image,const ImageType),
+  StripImage(Image *image),
+  SyncImage(Image *image);
 
 extern MagickExport void
   AllocateNextImage(const ImageInfo *,Image *),
@@ -1023,8 +1047,27 @@ extern MagickExport void
   ModifyImage(Image **,ExceptionInfo *),
   SetImageOpacity(Image *,const unsigned int);
 
+#if defined(MAGICK_IMPLEMENTATION)
+  /*
+    SetImageInfo flags specification.
+  */
+#  define SETMAGICK_FALSE    0x00000 /* MagickFalse ("read") */
+#  define SETMAGICK_TRUE     0x00001 /* MagickTrue ("write+rectify") */
+#  define SETMAGICK_READ     0x00002 /* Filespec will be read */
+#  define SETMAGICK_WRITE    0x00004 /* Filespec will be written */
+#  define SETMAGICK_RECTIFY  0x00008 /* Look for adjoin in filespec */
+#endif /* defined(MAGICK_IMPLEMENTATION) */
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
 
 #endif /* _MAGICK_IMAGE_H */
+
+/*
+ * Local Variables:
+ * mode: c
+ * c-basic-offset: 2
+ * fill-column: 78
+ * End:
+ */
