@@ -581,6 +581,7 @@
 #define RegisterLABELImage GmRegisterLABELImage
 #define RegisterLOCALEImage GmRegisterLOCALEImage
 #define RegisterLOGOImage GmRegisterLOGOImage
+#define RegisterMACImage GmRegisterMACImage
 #define RegisterMAPImage GmRegisterMAPImage
 #define RegisterMATImage GmRegisterMATImage
 #define RegisterMATTEImage GmRegisterMATTEImage
@@ -768,6 +769,7 @@
 #define UnregisterLABELImage GmUnregisterLABELImage
 #define UnregisterLOCALEImage GmUnregisterLOCALEImage
 #define UnregisterLOGOImage GmUnregisterLOGOImage
+#define UnregisterMACImage GmUnregisterMATImage
 #define UnregisterMAPImage GmUnregisterMAPImage
 #define UnregisterMATImage GmUnregisterMATImage
 #define UnregisterMATTEImage GmUnregisterMATTEImage
